summaryrefslogtreecommitdiff
path: root/pkgtools
diff options
context:
space:
mode:
authorrillig <rillig>2005-05-18 03:43:13 +0000
committerrillig <rillig>2005-05-18 03:43:13 +0000
commit4ca750a0fc5ab058d3b27a14fd088b4d7566718c (patch)
tree14325feff5863bea40cd40a94fbb40a4aa5a72d0 /pkgtools
parentc41eec7098eb8f794891ecaf546df4db5a86a36d (diff)
downloadpkgsrc-4ca750a0fc5ab058d3b27a14fd088b4d7566718c.tar.gz
Renamed PkgLint::Utils to PkgLint::Util, just for fun.
Diffstat (limited to 'pkgtools')
-rw-r--r--pkgtools/pkglint/files/pkglint.pl10
1 files changed, 5 insertions, 5 deletions
diff --git a/pkgtools/pkglint/files/pkglint.pl b/pkgtools/pkglint/files/pkglint.pl
index fc236c2c1ca..bf49595230a 100644
--- a/pkgtools/pkglint/files/pkglint.pl
+++ b/pkgtools/pkglint/files/pkglint.pl
@@ -11,7 +11,7 @@
# Freely redistributable. Absolutely no warranty.
#
# From Id: portlint.pl,v 1.64 1998/02/28 02:34:05 itojun Exp
-# $NetBSD: pkglint.pl,v 1.148 2005/05/18 03:38:03 rillig Exp $
+# $NetBSD: pkglint.pl,v 1.149 2005/05/18 03:43:13 rillig Exp $
#
# This version contains lots of changes necessary for NetBSD packages
# done by Hubert Feyrer <hubertf@netbsd.org>,
@@ -25,7 +25,7 @@
# an uppercase letter are not recognized as subroutines but as file handles.
#==========================================================================
-package PkgLint::Utils;
+package PkgLint::Util;
#==========================================================================
# This package is a catch-all for everything that does not fit in any other
# package. Currently it contains the boolean constants C<false> and C<true>.
@@ -40,7 +40,7 @@ BEGIN {
use constant false => 0;
use constant true => 1;
#== End of PkgLint::Utils =================================================
package PkgLint::Logging;
#==========================================================================
@@ -68,7 +68,7 @@ BEGIN {
log_error log_warning log_info
print_summary_and_exit set_verbose is_verbose
);
- import PkgLint::Utils qw(false true);
+ import PkgLint::Util qw(false true);
}
use constant NO_FILE => "";
@@ -222,7 +222,7 @@ use File::Basename;
use Cwd;
BEGIN {
- import PkgLint::Utils qw(false true);
+ import PkgLint::Util qw(false true);
import PkgLint::Logging qw(
NO_FILE NO_LINE_NUMBER
log_error log_warning log_info
@@ -40,7 +40,7 @@ BEGIN {
use constant false => 0;
use constant true => 1;
-#== End of PkgLint::Utils =================================================
+#== End of PkgLint::Util ==================================================
package PkgLint::Logging;
#==========================================================================